==> moniwiki-1.0.tgz: moniwiki/plugin/Board.php <==
<?php
// Copyright 2003 by Won-Kyu Park <wkpark at kldp.org>
// All rights reserved. Distributable under GPL see COPYING
// Gallery plugin for the MoniWiki
//
// Usage: [[Gallery]]
//
// $Id: Gallery.php,v 1.1 2003/06/17 20:24:11 wkpark Exp wkpark $
// vim:et:ts=2:

function macro_Board($formatter,$value) {
   global $DBInfo;

   # add some actions at the bottom of the page
   if (!in_array('Board',$formatter->actions))
     $formatter->actions[]='Board';

   if (!$value)
     $value=$formatter->page->name;
   $key=$DBInfo->pageToKeyname($value);

   $pages=$DBInfo->getLikePages($value."_2f\d+$");

   if (!$pages) return "<h3>"._("No articles found")."</h3>";
   asort($pages);

   $out.="<table border='0' cellpadding='2'>\n";

   while (list($dummy,$id) = each ($pages)) {
      $akey=$DBInfo->pageToKeyname($id);
      $size=filesize($DBInfo->text_dir."/".$akey);
      $fp=fopen($DBInfo->text_dir."/".$akey,"r");
      $line=fgets($fp,2048); # get the first line
      fclose($fp);
      list($user,$date,$title)=explode(" ",$line,3);
      $user=substr($user,2);

      if ($date && $date[10] == 'T') {
        $date[10]=' ';
        $time=strtotime($date." GMT");
        $date= date("m-d [h:i a]",$time);
      }

      $link=$formatter->link_tag($id,"",$title);
      $out.="<tr><td class='wiki'>$link</td>".
            "<td class='wiki'>$date</td><td class='wiki'>$user</td></tr>\n";
   }
   $out.="</table>\n";

   return $out;
}

function do_Board($formatter,$options) {
  global $DBInfo;
  global $HTTP_USER_AGENT;
  $COLS_MSIE = 80;
  $COLS_OTHER = 85;
  $cols = preg_match('/MSIE/', $HTTP_USER_AGENT) ? $COLS_MSIE : $COLS_OTHER;

  $rows=$options[rows] > 5 ? $options[rows]: 8;
  $cols=$options[cols] > 60 ? $options[cols]: $cols;

  $url=$formatter->link_url($formatter->page->urlname);
  $formatter->send_header("",$options);
  if (!$options[button_preview] && $options[savetext] && $options[title]) {
    $savetext=stripslashes($options[savetext]);
    $options[msg]=sprintf(_("Comment is added to \"%s\""),$options[page]);
    $formatter->send_title(sprintf(_("Add article to \"%s\""),$options[page]),"",$options);
    if ($options[id]=='Anonymous') $id=$_SERVER[REMOTE_ADDR];
    else $id=$options[id];
    $raw_body="$id @date@ $options[$title]\n$savetext";
    $page=new WikiPage($options[page]."/1");
    $page->write($raw_body);
    $DBInfo->savePage($page,"Add article to $options[page]",$options);

    $formatter->send_page();
  } else {
    $formatter->send_title(sprintf(_("Add article to \"%s\""),$options[page]),"",$options);
    print <<<EOS
<form method="post" action="$url">
Title: <input name="title" value='$options[title]' size="70" maxlength="70" style="width:200" /><br />
<textarea class="wiki" id="content" wrap="virtual" name="savetext"
 rows="$rows" cols="$cols" style="width:100%">$options[savetext]</textarea><br />
<input type="hidden" name="action" value="Boaroard" />
<input type="submit" value="Save" />&nbsp;
<input type="reset" value="Reset" />&nbsp;
<input type="submit" name="button_preview" value="Preview" />
$extra
</form>
EOS;
  }
  $formatter->show_hints();
  if ($options[button_preview] && $options[savetext]) {
    if ($options[title])
      $formatter->send_page("== $options[title] ==\n");
    $formatter->send_page($options[savetext]);
  }
  $formatter->send_footer("",$options);
  return;
}

?>

==> moniwiki-1.0.2.tgz: moniwiki/plugin/Board.php <==
<?php
// Copyright 2003 by Won-Kyu Park <wkpark at kldp.org>
// All rights reserved. Distributable under GPL see COPYING
// Gallery plugin for the MoniWiki
//
// Usage: [[Gallery]]
//
// $Id: Board.php,v 1.2 2003/08/15 21:30:36 wkpark Exp $
// vim:et:ts=2:

function macro_Board($formatter,$value) {
   global $DBInfo;

   # add some actions at the bottom of the page
   if (!in_array('Board',$formatter->actions))
     $formatter->actions[]='Board';

   if (!$value)
     $value=$formatter->page->name;
   $key=$DBInfo->pageToKeyname($value);

   $pages=$DBInfo->getLikePages($value."_2f\d+$");

   if (!$pages) return "<h3>"._("No articles found")."</h3>";
   asort($pages);

   $out.="<table border='0' cellpadding='2'>\n";

   while (list($dummy,$id) = each ($pages)) {
      $akey=$DBInfo->pageToKeyname($id);
      $size=filesize($DBInfo->text_dir."/".$akey);
      $fp=fopen($DBInfo->text_dir."/".$akey,"r");
      $line=fgets($fp,2048); # get the first line
      fclose($fp);
      list($user,$date,$title)=explode(" ",$line,3);
      $user=substr($user,2);

      if ($date && $date[10] == 'T') {
        $date[10]=' ';
        $time=strtotime($date." GMT");
        $date= date("m-d [h:i a]",$time);
      }

      $link=$formatter->link_tag($id,"",$title);
      $out.="<tr><td class='wiki'>$link</td>".
            "<td class='wiki'>$date</td><td class='wiki'>$user</td></tr>\n";
   }
   $out.="</table>\n";

   return $out;
}

function do_Board($formatter,$options) {
  global $DBInfo;
  global $HTTP_USER_AGENT;
  $COLS_MSIE = 80;
  $COLS_OTHER = 85;
  $cols = preg_match('/MSIE/', $HTTP_USER_AGENT) ? $COLS_MSIE : $COLS_OTHER;

  $rows=$options['rows'] > 5 ? $options['rows']: 8;
  $cols=$options['cols'] > 60 ? $options['cols']: $cols;

  $url=$formatter->link_url($formatter->page->urlname);
  $formatter->send_header("",$options);
  if (!$options['button_preview'] && $options['savetext'] && $options['title']) {
    $savetext=stripslashes($options['savetext']);
    $options['msg']=sprintf(_("Comment is added to \"%s\""),$options['page']);
    $formatter->send_title(sprintf(_("Add article to \"%s\""),$options['page']),"",$options);
    if ($options['id']=='Anonymous') $id=$_SERVER['REMOTE_ADDR'];
    else $id=$options['id'];
    $raw_body="#title $options[$title]\n##$id @date@\n$savetext";
    #$raw_body="$id @date@ $options[$title]\n$savetext";
    $page=new WikiPage($options['page']."/1");
    $page->write($raw_body);
    $DBInfo->savePage($page,"A article added to $options[page]",$options);

    $formatter->send_page();
  } else {
    $formatter->send_title(sprintf(_("Add article to \"%s\""),$options[page]),"",$options);
    print "<form method=\"post\" action=\"$url\">\n";
    print _("User").": <input name=\"user\" value='$options[user]' size=\"20\" maxlength=\"15\" />\n";
    print _("Email").": <input name=\"user\" value='$options[user]' size=\"20\" maxlength=\"15\" /><br />\n";
    print _("Password").": <input name=\"passwd\" value='$options[passwd]' size=\"20\" maxlength=\"15\" /><br />\n";
    print _("Title").": <input name=\"title\" value='$options[title]' size=\"70\" maxlength=\"70\" style=\"width:200\" /><br />\n";

    print <<<FORM
<textarea class="wiki" id="content" wrap="virtual" name="savetext"
 rows="$rows" cols="$cols" style="width:100%">$options[savetext]</textarea><br />
<input type="hidden" name="action" value="Boaroard" />
<input type="submit" value="Save" />&nbsp;
<input type="reset" value="Reset" />&nbsp;
<input type="submit" name="button_preview" value="Preview" />
$extra
</form>
FORM;
  }
  print macro_EditHints($formatter);
  if ($options['button_preview'] && $options['savetext']) {
    if ($options['title'])
      $formatter->send_page("== $options[title] ==\n");
    $formatter->send_page($options[savetext]);
  }
  $formatter->send_footer("",$options);
  return;
}

?>
